Appendix D: Zope Resources
##########################

At the time of this writing there is a multitude of sources for Zope
information on the Internet and in print. We've collected a number of the most
important links which you can use to find out more about Zope.

Zope Web Sites
==============

`Zope.org <http://www.zope.org>`_ is the official Zope website. It has
downloads, documentation, news, and lots of community resources.

`DZUG <http://dzug.org/>`_ was started as the main community site for the
German Zope community and combines documentation translated to German,
downloads, a portal for the various regional German Zope User Groups as well as
information about Zope-related events in Europe.

`Zope Italia <http://www.zope.it/>`_ forms the focal point for the Italian Zope
community with news, events information and local Zope group contacts.

Zope Documentation
==================

`ZopeWiki - A wiki for the Zope community <http://zopewiki.org/>`_ is a
community-run Zope documentation website set up by Simon Michael, author of the
famus ZWiki wiki product for Zope.

`Zope Developer's Guide <http://www.zope.org/DocProjects/DevGuide>`_ teaches
you how to write Zope products. It is somewhat outdated but cotains some
nuggets you don't find elsewhere.

(Other) Zope Books
==================

`The Zope Bible
<http://www.amazon.com/exec/obidos/ASIN/0764548573/qid=1030511472/sr=2-1/ref=sr_2_1/002-3988880-4512056>`_
by Scott Robertson and Michael Bernstein.

`The Book of Zope
<http://www.amazon.com/exec/obidos/ASIN/1886411573/qid=1030511472/sr=2-2/ref=sr_2_2/002-3988880-4512056>`_
by Beehive.

`The Zope Web Application Construction Kit
<http://www.amazon.com/exec/obidos/tg/detail/-/0672321335/qid=1030511472/sr=1-5/ref=sr_1_5/002-3988880-4512056?v=glance&amp;s=books>`_
edited by Martina Brockman, et. al.

`Zope: Web Application Development and Content Management
<http://www.amazon.com/exec/obidos/tg/detail/-/0735711100/qid=1030511472/sr=1-2/ref=sr_1_2/002-3988880-4512056?v=glance&amp;s=books>`_
edited by Steve Spicklemire et al.

`Zope: Timely, Practical, Reliable
<http://www.amazon.com/exec/obidos/tg/detail/-/0470844515/ref=ase_zopezone-20/102-5632760-7919306?v=glance&s=books>`_
written by Pierre Julien Grizel.

`The Zope Book
<http://www.amazon.com/exec/obidos/ASIN/0735711372/zopezone-20/102-5632760-7919306>`_
is the hardcover version of the original edition Zope Book on which this text
is based.

Mailing Lists
=============

`mail.zope.org <http://www.zope.org/Resources/MailingLists>`_ maintains a collection
of the many Zope mailing lists.

Python Information
==================

`Python.org <http://www.python.org>`_ has lots of information about Python
including a tutorial and reference documentation.

